---
name: Feature request
about: Request a new feature
title: "[Feature-Request] {Title of feature request}"
labels: enhancement
assignees: ''

---

### Start with the `why`:
Describe why this feature would be useful to you and to other users.

### Move to the `what`:
A clear and concise description of the feature you would like to get added to the `depthai`.

### Move to the `how`:
If you already have an idea of how this new feature could be implemented, describe it here.